@@ -1,6 +1,6 @@
 package Bundle::InterchangeKitchenSink;
 
-$VERSION = '0.07';
+$VERSION = '0.09';
 
 1;
 
@@ -46,7 +46,7 @@ Tie::ShadowHash
 
 Business::UPS
 
-SQL::Statement 0.1021
+SQL::Statement::Hash
 
 Storable
 
@@ -72,6 +72,12 @@ Tie::Watch
 
 Time::HiRes
 
+GD
+
+GD::Text::Align
+
+GD::Graph
+
 =head1 DESCRIPTION
 
 This bundle installs the prerequisites for Interchange as well as some
